# -*- coding: utf-8 -*-

"""
    Django-flash
    ~~~~~~~~~~~~

    Rails-like flash scope support for Django.

    :copyright: 2008-2009, Destaquenet Technology Solutions.
    :license: LGPL v3.
"""

__version__ = '1.4.2'

