<html>
    <head>
        <title>Simple template</title>
    </head>
    <body>
        <!-- Just some content, not used in unittests -->
        Flash context: {{ flash.message }}
    </body>
</html>
